.. _postgres_module:

:mod:`fabtools.postgres`
------------------------

.. automodule:: fabtools.postgres

    .. seealso:: :ref:`require_postgres_module`

    Manage users
    ~~~~~~~~~~~~

    .. autofunction:: user_exists
    .. autofunction:: create_user

    Manage databases
    ~~~~~~~~~~~~~~~~

    .. autofunction:: database_exists
    .. autofunction:: create_database
